pub enum InitialCamera {
Orthographic2d(f32),
Orthographic3d(f32),
}Expand description
Configure the initial camera view and set how the camera will be controlled.
Variants
Orthographic2d(f32)
Two dimensional top down camera showing the xy plane.
The single field sets the height of the visible area. The width is set automatically based on the window dimensions.
Controls:
- Left click and drag to pan.
- Scroll to zoom.
Orthographic3d(f32)
Three dimensional front down camera showing the xy plane.
The single field sets the height of the visible area. The width is set automatically based on the window dimensions.
Controls:
- TODO