pub fn add_default_plugins(app: &mut App)Expand description
Construct the default plugins.
This helper adds Bevy’s DefaultPlugins by default. When the
doc-example feature is enabled, it adds a modified set of plugins
for the web.
pub fn add_default_plugins(app: &mut App)Construct the default plugins.
This helper adds Bevy’s DefaultPlugins by default. When the
doc-example feature is enabled, it adds a modified set of plugins
for the web.