pub struct Ellipse<T> { /* private fields */ }Expand description
Represent an entity with a 2D ellipse in the xy plane.
The base representation has semi-axes (0.5, 0.5). Provide per-item axes
in sync to render ellipses of different sizes and aspect ratios.
Nominally, the z coordinate of the ellipses should be set to 0. Choose a different
value to control the back to front draw order.
To use:
Implementations
Sourceimpl<T: Send + Sync + 'static> Ellipse<T>
impl<T: Send + Sync + 'static> Ellipse<T>
Sourcepub fn setup(
material: In<MaterialParameters>,
commands: Commands<'_, '_>,
buffers: ResMut<'_, Assets<ShaderStorageBuffer>>,
meshes: ResMut<'_, Assets<Mesh>>,
materials: ResMut<'_, Assets<Material>>,
)
pub fn setup( material: In<MaterialParameters>, commands: Commands<'_, '_>, buffers: ResMut<'_, Assets<ShaderStorageBuffer>>, meshes: ResMut<'_, Assets<Mesh>>, materials: ResMut<'_, Assets<Material>>, )
Create assets to render ellipses.
Sourcepub fn sync<I>(
commands: &mut Commands<'_, '_>,
ellipse_representation: Res<'_, Representation<T>>,
query: Query<'_, '_, (Entity, &mut Transform), With<Self>>,
ellipses: I,
)
pub fn sync<I>( commands: &mut Commands<'_, '_>, ellipse_representation: Res<'_, Representation<T>>, query: Query<'_, '_, (Entity, &mut Transform), With<Self>>, ellipses: I, )
Copy the current positions of simulation particles to bevy entities.