Material

Struct Material 

pub struct Material { /* private fields */ }
Control how ellipses are rendered.

Ellipses are always opaque and alpha in any background color is ignored.

By default Material is initialized with only one background color. Color the instances differently by setting more than one color with set_background_colors. The color of each ellipse is given by background_colors[tag % len(background_colors)] so you may set fewer colors than there are ellipses. sync assigns tag values in increasing order to each primitive.

The background_color tints the texture by multiplication. With a None texture (the default), background_color sets the exact color of the ellipses.

Set the initial material by piping MaterialParameters into Ellipse::setup. After it is initialized, change the material during execution via the material field inResMut<ellipse::Representation<A>>.

Implementations

Source

impl Material

pub fn set_background_colors( &mut self, buffers: ResMut<'_, Assets<ShaderStorageBuffer>>, colors: &[LinearRgba], )

Set new background colors.

Panics

WebGL2 builds (identified by the wasm32 target without the webgpu feature) support only 1024 background colors.

Desktop target builds or wasm32 target builds with webgpu support a much larger number of colors and will not panic.