HoomdBevyPlugin

Struct HoomdBevyPlugin 

pub struct HoomdBevyPlugin<S> {
    pub initial_settings: Settings,
    pub simulation: S,
}
Interface hoomd-rs simulations with the Bevy game engine.

HoomdBevyPlugin is used by all the hoomd-rs examples that create interactive graphical displays of simulations. Specifically, it implements:

  • Camera controls (2D and 3D separately).
  • Simulation step and frame pacing, with a limited number of steps per second.
  • Pause and advance by single step controls.
  • Screenshots.
  • A GUI that provides usage instructions, settings, and controls.

The caller must:

  • Add the EguiPlugin.
  • Provide type that implements Simulation.
  • Add a sync Update system that populates (and removes) entities for rendering. See representation for helper code.

The caller may optionally:

  • Add UI to the upper left and/or right corners of the screen.
  • Implement custom keyboard and/or GUI controls.

To keep individual example scripts short and understandable, hoomd-bevy should implement as much common code as possible.

Examples

See any one of the many hoomd-rs examples that use HoomdBevyPlugin.

Fields

initial_settings: Settings

Configuration to use at application start (may be changed later).

simulation: S

The simulation to advance and display interactively.

Implementations

Source

impl<Sim> HoomdBevyPlugin<Sim>
where Sim: Resource + Simulation,

pub const SPS: DiagnosticPath

Bevy diagnostic that counts the number of steps executed per second.

pub const CLEAR: Color

Clear the window to this color before rendering each frame.

pub const UI_OFFSET: f32 = 12f32

Offset the interface from the edge of the screen.

pub fn is_paused(state: Res<'_, UiState>) -> bool

Test if the simulation is paused in run_if.

pub fn build(self, app: &mut App)

Build the plugin.

HoomdBevyPlugin does not implement [Plugin] and cannot be used with add_plugins so that the build method can consume self. This allows build to take ownership of the simulation field and create the appropriate Bevy [Resource].

Panics
  • When EguiPlugin is not added before calling build.