pub struct Settings {
pub frame_budget_fraction: f32,
pub sps_limit: f32,
pub camera: InitialCamera,
pub zoom_range: Range<f32>,
pub camera_sensitivity: f32,
}Expand description
Store parameters that influence how the simulation is executed.
Fields
frame_budget_fraction: f32Maximum fraction (0.0 to 1.0) of the frame time to use advancing the simulation.
sps_limit: f32Maximum number of steps per second to advance the simulation.
camera: InitialCameraInitial camera.
zoom_range: Range<f32>Clamp the orthographic camera’s scale to this range.
camera_sensitivity: f32Camera sensitivity.