pub struct HoomdBevyPlugin<S> {
pub initial_settings: Settings,
pub simulation: S,
}Expand description
Interface hoomd-rs simulations with the Bevy game engine.
HoomdBevyPlugin is used by all the hoomd-rs examples that create
interactive graphical displays of simulations. Specifically, it implements:
- Camera controls (2D and 3D separately).
- Simulation step and frame pacing, with a limited number of steps per second.
- Pause and advance by single step controls.
- Screenshots.
- A GUI that provides usage instructions, settings, and controls.
The caller must:
- Add the
EguiPlugin. - Provide type that implements
Simulation. - Add a
syncUpdatesystem that populates (and removes) entities for rendering. Seerepresentationfor helper code.
The caller may optionally:
- Add UI to the upper left and/or right corners of the screen.
- Implement custom keyboard and/or GUI controls.
To keep individual example scripts short and understandable, hoomd-bevy should
implement as much common code as possible.
Examples
See any one of the many hoomd-rs examples that use HoomdBevyPlugin.
Fields
initial_settings: SettingsConfiguration to use at application start (may be changed later).
simulation: SThe simulation to advance and display interactively.
Implementations
Sourceimpl<Sim> HoomdBevyPlugin<Sim>where
Sim: Resource + Simulation,
impl<Sim> HoomdBevyPlugin<Sim>where
Sim: Resource + Simulation,
Sourcepub const SPS: DiagnosticPath
pub const SPS: DiagnosticPath
Bevy diagnostic that counts the number of steps executed per second.
Sourcepub fn build(self, app: &mut App)
pub fn build(self, app: &mut App)
Build the plugin.
HoomdBevyPlugin does not implement [Plugin] and cannot be used with
add_plugins so that the build method can consume self. This allows
build to take ownership of the simulation field and create the appropriate
Bevy [Resource].
Panics
- When
EguiPluginis not added before callingbuild.